@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __CHEESE_FILE_UTIL_H__
@@ -25,6 +24,8 @@ void cheese_fileutil_init();
 void cheese_fileutil_finalize();
 gchar *cheese_fileutil_get_photo_path(void);
 gchar *cheese_fileutil_get_photo_filename(int);
-void cheese_fileutil_photos_monitor_cb(GnomeVFSMonitorHandle *, const gchar *, const gchar *, GnomeVFSMonitorEventType);
+gchar *cheese_fileutil_get_video_path(void);
+gchar *cheese_fileutil_get_video_filename(void);
+void cheese_fileutil_monitor_cb(GnomeVFSMonitorHandle *, const gchar *, const gchar *, GnomeVFSMonitorEventType);
 
 #endif /* __CHEESE_FILE_UTIL_H__ */
