@@ -14,11 +14,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
@@ -27,7 +25,7 @@
 
 #include "cheese-config.h"
 #include "cheese.h"
-#include "cheese-pipeline-photo.h"
+#include "cheese-pipeline.h"
 #include "cheese-fileutil.h"
 #include "cheese-thumbnails.h"
 #include "cheese-window.h"
@@ -37,15 +35,13 @@ struct _cheese_window cheese_window;
 struct _thumbnails thumbnails;
 
 GnomeVFSMonitorHandle *monitor_handle = NULL;
-Pipeline *PipelinePhoto;
 
 void
 on_cheese_window_close_cb(GtkWidget *widget, gpointer data)
 {
-  pipeline_set_stop(PipelinePhoto);
-  g_object_unref(G_OBJECT(PipelinePhoto));
   gnome_vfs_monitor_cancel(monitor_handle);
 
+  cheese_pipeline_finalize();
   cheese_effects_widget_finalize();
   cheese_window_finalize();
   cheese_thumbnails_finalize();
@@ -76,6 +72,14 @@ main(int argc, char **argv)
   path = cheese_fileutil_get_photo_path();
   uri = gnome_vfs_uri_new(path);
 
+  if (!gnome_vfs_uri_exists(uri)) {
+    gnome_vfs_make_directory_for_uri(uri, 0775);
+    g_mkdir_with_parents(path, 0775);
+    g_print("creating new directory: %s\n", path);
+  }
+  path = cheese_fileutil_get_video_path();
+  uri = gnome_vfs_uri_new(path);
+
   if (!gnome_vfs_uri_exists(uri)) {
     gnome_vfs_make_directory_for_uri(uri, 0775);
     g_mkdir_with_parents(path, 0775);
@@ -86,28 +90,26 @@ main(int argc, char **argv)
 
   cheese_effects_widget_init();
 
-  PipelinePhoto = PIPELINE(pipeline_new());
-  pipeline_create(PipelinePhoto);
-  pipeline_set_play(PipelinePhoto);
-
   cheese_thumbnails_init();
-  gtk_icon_view_set_model(GTK_ICON_VIEW(thumbnails.iconview), GTK_TREE_MODEL(thumbnails.store));
+  gtk_icon_view_set_model(GTK_ICON_VIEW(thumbnails.iconview),
+      GTK_TREE_MODEL(thumbnails.store));
   cheese_thumbnails_fill_thumbs();
 
   gnome_vfs_monitor_add(&monitor_handle, cheese_fileutil_get_photo_path(),
       GNOME_VFS_MONITOR_DIRECTORY,
-      (GnomeVFSMonitorCallback)cheese_fileutil_photos_monitor_cb, NULL);
-
-  g_signal_connect(G_OBJECT(cheese_window.window), "destroy",
-      G_CALLBACK(on_cheese_window_close_cb), NULL);
-  g_signal_connect(G_OBJECT(cheese_window.widgets.take_picture), "clicked",
-      G_CALLBACK(pipeline_button_clicked), PipelinePhoto);
-  g_signal_connect(cheese_window.widgets.screen, "expose-event",
-      G_CALLBACK(cheese_window_expose_cb), PipelinePhoto);
-  g_signal_connect(G_OBJECT(cheese_window.widgets.button_effects), "clicked",
-      G_CALLBACK(cheese_window_change_effect), PipelinePhoto);
+      (GnomeVFSMonitorCallback)cheese_fileutil_monitor_cb, NULL);
+  gnome_vfs_monitor_add(&monitor_handle, cheese_fileutil_get_video_path(),
+      GNOME_VFS_MONITOR_DIRECTORY,
+      (GnomeVFSMonitorCallback)cheese_fileutil_monitor_cb, NULL);
 
   gtk_widget_show_all(cheese_window.window);
+
+  cheese_pipeline_init();
+  cheese_pipeline_set_play();
+
+  g_signal_connect(cheese_window.widgets.screen, "expose-event",
+      G_CALLBACK(cheese_window_expose_cb), NULL);
+
   gtk_main();
 
   return EXIT_SUCCESS;
